You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@spamassassin.apache.org by mm...@apache.org on 2013/06/06 12:11:49 UTC

svn commit: r1490223 - in /spamassassin/trunk: ./ lib/Mail/ lib/Mail/SpamAssassin/ lib/Mail/SpamAssassin/Conf/ lib/Mail/SpamAssassin/Logger/ lib/Mail/SpamAssassin/Plugin/ spamc/

Author: mmartinec
Date: Thu Jun  6 10:11:48 2013
New Revision: 1490223

URL: http://svn.apache.org/r1490223
Log:
use common style in comments: backwards compatible -> backward compatible; see Wikipedia and http://itknowledgeexchange.techtarget.com/writing-for-business/backward-compatible-or-backwards-compatible/

Modified:
    spamassassin/trunk/README
    spamassassin/trunk/UPGRADE
    spamassassin/trunk/lib/Mail/SpamAssassin.pm
    spamassassin/trunk/lib/Mail/SpamAssassin/AsyncLoop.pm
    spamassassin/trunk/lib/Mail/SpamAssassin/Conf.pm
    spamassassin/trunk/lib/Mail/SpamAssassin/Conf/Parser.pm
    spamassassin/trunk/lib/Mail/SpamAssassin/Logger/File.pm
    spamassassin/trunk/lib/Mail/SpamAssassin/PerMsgStatus.pm
    spamassassin/trunk/lib/Mail/SpamAssassin/Plugin.pm
    spamassassin/trunk/lib/Mail/SpamAssassin/Plugin/ASN.pm
    spamassassin/trunk/lib/Mail/SpamAssassin/Plugin/AutoLearnThreshold.pm
    spamassassin/trunk/lib/Mail/SpamAssassin/Plugin/RelayCountry.pm
    spamassassin/trunk/spamc/spamc.c

Modified: spamassassin/trunk/README
URL: http://svn.apache.org/viewvc/spamassassin/trunk/README?rev=1490223&r1=1490222&r2=1490223&view=diff
==============================================================================
--- spamassassin/trunk/README (original)
+++ spamassassin/trunk/README Thu Jun  6 10:11:48 2013
@@ -80,7 +80,7 @@ Upgrading SpamAssassin
 
 IMPORTANT: If you are upgrading from a previous major version of
 SpamAssassin, please be sure to read the notes in UPGRADE to find out
-what has changed in a non-backwards compatible way.
+what has changed in a non- backward compatible way.
 
 
 Installing SpamAssassin

Modified: spamassassin/trunk/UPGRADE
URL: http://svn.apache.org/viewvc/spamassassin/trunk/UPGRADE?rev=1490223&r1=1490222&r2=1490223&view=diff
==============================================================================
--- spamassassin/trunk/UPGRADE (original)
+++ spamassassin/trunk/UPGRADE Thu Jun  6 10:11:48 2013
@@ -165,7 +165,7 @@ Note for Users Upgrading to SpamAssassin
 
 - The "sa-learn --rebuild" command has been deprecated; please use
   "sa-learn --sync" instead.  The --rebuild option will remain temporarily
-  for backwards compatability.
+  for backward compatability.
 
 - The Bayesian storage modules have been completely re-written and now
   include Berkeley DB (DBM) storage as well as SQL based storage (see

Modified: spamassassin/trunk/lib/Mail/SpamAssassin.pm
URL: http://svn.apache.org/viewvc/spamassassin/trunk/lib/Mail/SpamAssassin.pm?rev=1490223&r1=1490222&r2=1490223&view=diff
==============================================================================
--- spamassassin/trunk/lib/Mail/SpamAssassin/AsyncLoop.pm (original)
+++ spamassassin/trunk/lib/Mail/SpamAssassin/AsyncLoop.pm Thu Jun  6 10:11:48 2013
@@ -612,7 +612,7 @@ sub set_response_packet {
   $self->{finished}->{$id} = 1;  # only key existence matters, any value
   $timestamp = time  if !defined $timestamp;
   my $pending = $self->{pending_lookups};
-  if (!defined $key) {  # backwards compatibility with 3.2.3 and older plugins
+  if (!defined $key) {  # backward compatibility with 3.2.3 and older plugins
     # a third-party plugin did not provide $key in a call, search for it:
     if ($id eq $pending->{$id}->{id}) {  # I feel lucky, key==id ?
       $key = $id;

Modified: spamassassin/trunk/lib/Mail/SpamAssassin/Conf.pm
URL: http://svn.apache.org/viewvc/spamassassin/trunk/lib/Mail/SpamAssassin/Conf.pm?rev=1490223&r1=1490222&r2=1490223&view=diff
==============================================================================
--- spamassassin/trunk/lib/Mail/SpamAssassin/Conf.pm (original)
+++ spamassassin/trunk/lib/Mail/SpamAssassin/Conf.pm Thu Jun  6 10:11:48 2013
@@ -185,7 +185,7 @@ name is still accepted, but is deprecate
 
   push (@cmds, {
     setting => 'required_score',
-    aliases => ['required_hits'],       # backwards compat
+    aliases => ['required_hits'],       # backward compatible
     default => 5,
     type => $CONF_TYPE_NUMERIC,
   });

Modified: spamassassin/trunk/lib/Mail/SpamAssassin/Conf/Parser.pm
URL: http://svn.apache.org/viewvc/spamassassin/trunk/lib/Mail/SpamAssassin/Conf/Parser.pm?rev=1490223&r1=1490222&r2=1490223&view=diff
==============================================================================
--- spamassassin/trunk/lib/Mail/SpamAssassin/Conf/Parser.pm (original)
+++ spamassassin/trunk/lib/Mail/SpamAssassin/Conf/Parser.pm Thu Jun  6 10:11:48 2013
@@ -393,7 +393,7 @@ sub parse {
       # "3.0.x" versions:
       ## make sure it's a numeric value
       #$value += 0.0;
-      ## convert 3.000000 -> 3.0, stay backwards compatible ...
+      ## convert 3.000000 -> 3.0, stay backward compatible ...
       #$ver =~ s/^(\d+)\.(\d{1,3}).*$/sprintf "%d.%d", $1, $2/e;
       #$value =~ s/^(\d+)\.(\d{1,3}).*$/sprintf "%d.%d", $1, $2/e;
 

Modified: spamassassin/trunk/lib/Mail/SpamAssassin/Logger/File.pm
URL: http://svn.apache.org/viewvc/spamassassin/trunk/lib/Mail/SpamAssassin/Logger/File.pm?rev=1490223&r1=1490222&r2=1490223&view=diff
==============================================================================
--- spamassassin/trunk/lib/Mail/SpamAssassin/Logger/File.pm (original)
+++ spamassassin/trunk/lib/Mail/SpamAssassin/Logger/File.pm Thu Jun  6 10:11:48 2013
@@ -86,7 +86,7 @@ sub log_message {
   my $timestamp;
   my $fmt = $self->{timestamp_fmt};
   if (!defined $fmt) {
-    $timestamp = scalar localtime;  # default, backwards compatibility
+    $timestamp = scalar localtime;  # default, backward compatibility
   } elsif ($fmt eq '') {
     $timestamp = '';
   } else {

Modified: spamassassin/trunk/lib/Mail/SpamAssassin/PerMsgStatus.pm
URL: http://svn.apache.org/viewvc/spamassassin/trunk/lib/Mail/SpamAssassin/PerMsgStatus.pm?rev=1490223&r1=1490222&r2=1490223&view=diff
==============================================================================
--- spamassassin/trunk/lib/Mail/SpamAssassin/PerMsgStatus.pm (original)
+++ spamassassin/trunk/lib/Mail/SpamAssassin/PerMsgStatus.pm Thu Jun  6 10:11:48 2013
@@ -2531,7 +2531,7 @@ description is used.
 
 =back
 
-Backwards compatibility: the two mandatory arguments have been part of this API
+Backward compatibility: the two mandatory arguments have been part of this API
 since SpamAssassin 2.x.  The optional I<name=<gt>value> pairs, however, are a
 new addition in SpamAssassin 3.2.0.
 

Modified: spamassassin/trunk/lib/Mail/SpamAssassin/Plugin.pm
URL: http://svn.apache.org/viewvc/spamassassin/trunk/lib/Mail/SpamAssassin/Plugin.pm?rev=1490223&r1=1490222&r2=1490223&view=diff
==============================================================================
--- spamassassin/trunk/lib/Mail/SpamAssassin/Plugin.pm (original)
+++ spamassassin/trunk/lib/Mail/SpamAssassin/Plugin.pm Thu Jun  6 10:11:48 2013
@@ -680,7 +680,7 @@ format of:
 NOTE: This data structure has changed since it was originally introduced
 in version 3.0.0.  The values are no longer perl anonymous hashes, they
 are a single string containing the raw token value.  You can test for
-backwards compatibility by checking to see if the value for a key is a
+backward compatibility by checking to see if the value for a key is a
 reference to a perl HASH, for instance:
 
 if (ref($toksref->{$sometokenkey}) eq 'HASH') {...
@@ -1196,7 +1196,7 @@ Different rule types receive different i
 The configuration file arguments will be passed in after the standard
 arguments.
 
-=head1 BACKWARDS COMPATIBILITY
+=head1 BACKWARD COMPATIBILITY
 
 Note that if you write a plugin and need to determine if a particular
 helper method is supported on C<Mail::SpamAssassin::Plugin>, you

Modified: spamassassin/trunk/lib/Mail/SpamAssassin/Plugin/ASN.pm
URL: http://svn.apache.org/viewvc/spamassassin/trunk/lib/Mail/SpamAssassin/Plugin/ASN.pm?rev=1490223&r1=1490222&r2=1490223&view=diff
==============================================================================
--- spamassassin/trunk/lib/Mail/SpamAssassin/Plugin/AutoLearnThreshold.pm (original)
+++ spamassassin/trunk/lib/Mail/SpamAssassin/Plugin/AutoLearnThreshold.pm Thu Jun  6 10:11:48 2013
@@ -126,7 +126,7 @@ With C<bayes_auto_learn_on_error> off, a
 even if bayes classifier already agrees with the new classification (i.e.
 yielded BAYES_00 for what we are now trying to teach it as ham, or yielded
 BAYES_99 for spam). This is a traditional setting, the default was chosen
-to retain backwards compatibility.
+to retain backward compatibility.
 
 With C<bayes_auto_learn_on_error> turned on, autolearning will be performed
 only when a bayes classifier had a different opinion from what the autolearner

Modified: spamassassin/trunk/lib/Mail/SpamAssassin/Plugin/RelayCountry.pm
URL: http://svn.apache.org/viewvc/spamassassin/trunk/lib/Mail/SpamAssassin/Plugin/RelayCountry.pm?rev=1490223&r1=1490222&r2=1490223&view=diff
==============================================================================
--- spamassassin/trunk/lib/Mail/SpamAssassin/Plugin/RelayCountry.pm (original)
+++ spamassassin/trunk/lib/Mail/SpamAssassin/Plugin/RelayCountry.pm Thu Jun  6 10:11:48 2013
@@ -32,7 +32,7 @@ header markup.
 
 =head1 REQUIREMENT
 
-This plugin requires the Geo::IP module from CPAN. For backwards
+This plugin requires the Geo::IP module from CPAN. For backward
 compatibility IP::Country::Fast is used if Geo::IP is not installed.
 
 =cut

Modified: spamassassin/trunk/spamc/spamc.c
URL: http://svn.apache.org/viewvc/spamassassin/trunk/spamc/spamc.c?rev=1490223&r1=1490222&r2=1490223&view=diff
==============================================================================
--- spamassassin/trunk/spamc/spamc.c (original)
+++ spamassassin/trunk/spamc/spamc.c Thu Jun  6 10:11:48 2013
@@ -321,7 +321,7 @@ read_args(int argc, char **argv,
 #endif
             case 'f':
             {
-                /* obsolete, backwards compat */
+                /* obsolete, backward compat */
                 break;
             }
             case 'K':
--- spamassassin/trunk/lib/Mail/SpamAssassin.pm (original)
+++ spamassassin/trunk/lib/Mail/SpamAssassin.pm Thu Jun  6 10:11:48 2013
@@ -281,7 +281,7 @@ value will be empty. Currently no built-
 entry overrides previous one, e.g. ASN,NOASN,ASN,TIMING,NOASN is equivalent
 to TIMING,NOASN.
 
-For backwards compatibility, all tags available as of version 3.2.4 will
+For backward compatibility, all tags available as of version 3.2.4 will
 be available by default (unless disabled by NOtag), even if not requested
 through need_tags option. Future versions may provide new tags conditionally
 available.
@@ -335,7 +335,7 @@ library.
 
 This setting requires the caller to decide when to call srand().
 This choice may be desired to preserve the entropy of a PRNG.  The default
-value of skip_prng_reseeding is false to maintain backwards compatibility. 
+value of skip_prng_reseeding is false to maintain backward compatibility. 
 
 This option should only be set by a caller if it calls srand() upon spawning
 child processes.  Unless you are certain you need it, leave this setting as
@@ -395,7 +395,7 @@ sub new {
   if (!defined $self) { $self = { }; }
   bless ($self, $class);
 
   # basic backwards compatibility; debug used to be a boolean.
   # translate that into 'all', which is what it meant before 3.1.0.
   if ($self->{debug} && $self->{debug} eq '1') {
     $self->{debug} = 'all';
@@ -395,7 +395,7 @@ sub new {
   bless ($self, $class);
 
-  # basic backwards compatibility; debug used to be a boolean.
+  # basic backward compatibility; debug used to be a boolean.
   # translate that into 'all', which is what it meant before 3.1.0.
   if ($self->{debug} && $self->{debug} eq '1') {

Modified: spamassassin/trunk/lib/Mail/SpamAssassin/AsyncLoop.pm
URL: http://svn.apache.org/viewvc/spamassassin/trunk/lib/Mail/SpamAssassin/AsyncLoop.pm?rev=1490223&r1=1490222&r2=1490223&view=diff
==============================================================================
--- spamassassin/trunk/lib/Mail/SpamAssassin/Plugin/ASN.pm (original)
+++ spamassassin/trunk/lib/Mail/SpamAssassin/Plugin/ASN.pm Thu Jun  6 10:11:48 2013
@@ -23,7 +23,7 @@
 # Modifications by D. Stussy, 2010-12-15 (SpamAssassin enhancement #6484):
 #
 # Since SA 3.4.0 a fixed text prefix (such as AS) to each ASN is configurable
 # through an asn_prefix directive. Its value is 'AS' by default for backwards
 # compatibility with SA 3.3.*, but is rather redundant and can be set to an
 # empty string for clarity if desired.
 #
@@ -185,7 +185,7 @@ Removes any previously declared I<asn_lo
 
 The string specified in the argument is prepended to each ASN when storing
 it as a tag. This prefix is rather redundant, but its default value 'AS'
-is kept for backwards compatibility with versions of SpamAssassin earlier
+is kept for backward compatibility with versions of SpamAssassin earlier
 than 3.4.0. A sensible setting is an empty string. The argument may be (but
 need not be) enclosed in single or double quotes for clarity.
 
@@ -23,7 +23,7 @@
 #
 # Since SA 3.4.0 a fixed text prefix (such as AS) to each ASN is configurable
-# through an asn_prefix directive. Its value is 'AS' by default for backwards
+# through an asn_prefix directive. Its value is 'AS' by default for backward
 # compatibility with SA 3.3.*, but is rather redundant and can be set to an
 # empty string for clarity if desired.

Modified: spamassassin/trunk/lib/Mail/SpamAssassin/Plugin/AutoLearnThreshold.pm
URL: http://svn.apache.org/viewvc/spamassassin/trunk/lib/Mail/SpamAssassin/Plugin/AutoLearnThreshold.pm?rev=1490223&r1=1490222&r2=1490223&view=diff
==============================================================================